@@ -20,7 +20,13 @@ class TestCLLocationManager (TestCase):
         self.assertEqual(kCLAuthorizationStatusNotDetermined, 0)
         self.assertEqual(kCLAuthorizationStatusRestricted, 1)
         self.assertEqual(kCLAuthorizationStatusDenied, 2)
-        self.assertEqual(kCLAuthorizationStatusAuthorized, 3)
+        self.assertEqual(kCLAuthorizationStatusAuthorizedAlways, 3)
+        self.assertEqual(kCLAuthorizationStatusAuthorized, kCLAuthorizationStatusAuthorizedAlways)
+
+        self.assertEqual(CLActivityTypeOther, 1)
+        self.assertEqual(CLActivityTypeAutomotiveNavigation, 2)
+        self.assertEqual(CLActivityTypeFitness, 3)
+        self.assertEqual(CLActivityTypeOtherNavigation, 4)
 
     @min_os_level('10.7')
     def testMethods10_7(self):
@@ -30,5 +36,13 @@ class TestCLLocationManager (TestCase):
         self.assertResultIsBOOL(CLLocationManager.regionMonitoringAvailable)
         self.assertResultIsBOOL(CLLocationManager.regionMonitoringEnabled)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        self.assertResultIsBOOL(CLLocationManager.deferredLocationUpdatesAvailable)
+
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(CLLocationManager.isMonitoringAvailableForClass_)
+
 if __name__ == "__main__":
     main()
